Ocyan plugin contact_form
=========================

Installation
------------
Add `ocyan.plugin.contact_form` to your projects dependencies.

Description
-----------

The contact form plugin adds a streamfield block to wagtail that renders as
a contact form, with captcha. An email will be sent to the website order
containing the contact request.

The fields in the contact form are:

- name
- phone number (not required)
- email address
- message
- Verification with Captcha.


Configuration
-------------
* Email_from: 
	* The Email address that the website uses to send the contact form from.
* Email_to:
	* The Email address that the website uses to send the contact form to.

For example:

```json
    "contact_form": {
      "email_from": "xxxxxx@xxx.xxx",
      "email_to": "xxxxxx@xxx.xxx"
    },
```